@@ -26,6 +26,7 @@
 #include <algorithm>
 #include <random>
 #include <cassert>
+#include <climits>
 
 #include "OpAmp.h"
 #include "Spline.h"
@@ -37,6 +38,34 @@ namespace reSIDfp
 
 class FilterModelConfig
 {
+public:
+    // The highpass summer has 2 - 6 inputs (bandpass, lowpass, and 0 - 4 voices).
+    template<int i>
+    struct summer_offset
+    {
+        static constexpr int value = summer_offset<i - 1>::value + ((2 + i - 1) << 16);
+    };
+
+    // The mixer has 0 - 7 inputs (0 - 4 voices and 0 - 3 filter outputs).
+    template<int i>
+    struct mixer_offset
+    {
+        static constexpr int value = mixer_offset<i - 1>::value + ((i - 1) << 16);
+    };
+
+protected:
+    static inline unsigned short to_ushort_dither(double x, double d_noise)
+    {
+        const int tmp = static_cast<int>(x + d_noise);
+        assert((tmp >= 0) && (tmp <= USHRT_MAX));
+        return static_cast<unsigned short>(tmp);
+    }
+
+    static inline unsigned short to_ushort(double x)
+    {
+        return to_ushort_dither(x, 0.5);
+    }
+
 private:
     /*
      * Hack to add quick dither when converting values from float to int
@@ -93,10 +122,10 @@ protected:
 
     /// Lookup tables for gain and summer op-amps in output stage / filter.
     //@{
-    unsigned short* mixer[8];       //-V730_NOINIT this is initialized in the derived class constructor
-    unsigned short* summer[5];      //-V730_NOINIT this is initialized in the derived class constructor
-    unsigned short* volume[16];     //-V730_NOINIT this is initialized in the derived class constructor
-    unsigned short* resonance[16];  //-V730_NOINIT this is initialized in the derived class constructor
+    unsigned short* mixer;          //-V730_NOINIT this is initialized in the derived class constructor
+    unsigned short* summer;         //-V730_NOINIT this is initialized in the derived class constructor
+    unsigned short* volume;         //-V730_NOINIT this is initialized in the derived class constructor
+    unsigned short* resonance;      //-V730_NOINIT this is initialized in the derived class constructor
     //@}
 
     /// Reverse op-amp transfer function.
@@ -153,6 +182,7 @@ protected:
     {
         const double r_N16 = 1. / N16;
 
+        int idx = 0;
         for (int i = 0; i < 5; i++)
         {
             const int idiv = 2 + i;        // 2 - 6 input "resistors".
@@ -160,12 +190,11 @@ protected:
             const double n = idiv;
             const double r_idiv = 1. / idiv;
             opampModel.reset();
-            summer[i] = new unsigned short[size];
 
             for (int vi = 0; vi < size; vi++)
             {
                 const double vin = vmin + vi * r_N16 * r_idiv; /* vmin .. vmax */
-                summer[i][vi] = getNormalizedValue(opampModel.solve(n, vin));
+                summer[idx++] = getNormalizedValue(opampModel.solve(n, vin));
             }
         }
     }
@@ -182,6 +211,7 @@ protected:
     {
         const double r_N16 = 1. / N16;
 
+        int idx = 0;
         for (int i = 0; i < 8; i++)
         {
             const int idiv = (i == 0) ? 1 : i;
@@ -189,12 +219,11 @@ protected:
             const double n = i * nRatio;
             const double r_idiv = 1. / idiv;
             opampModel.reset();
-            mixer[i] = new unsigned short[size];
 
             for (int vi = 0; vi < size; vi++)
             {
                 const double vin = vmin + vi * r_N16 * r_idiv; /* vmin .. vmax */
-                mixer[i][vi] = getNormalizedValue(opampModel.solve(n, vin));
+                mixer[idx++] = getNormalizedValue(opampModel.solve(n, vin));
             }
         }
     }
@@ -210,17 +239,17 @@ protected:
     {
         const double r_N16 = 1. / N16;
 
+        int idx = 0;
         for (int n8 = 0; n8 < 16; n8++)
         {
-            const int size = 1 << 16;
+            constexpr int size = 1 << 16;
             const double n = n8 / nDivisor;
             opampModel.reset();
-            volume[n8] = new unsigned short[size];
 
             for (int vi = 0; vi < size; vi++)
             {
                 const double vin = vmin + vi * r_N16; /* vmin .. vmax */
-                volume[n8][vi] = getNormalizedValue(opampModel.solve(n, vin));
+                volume[idx++] = getNormalizedValue(opampModel.solve(n, vin));
             }
         }
     }
@@ -236,25 +265,25 @@ protected:
     {
         const double r_N16 = 1. / N16;
 
+        int idx = 0;
         for (int n8 = 0; n8 < 16; n8++)
         {
-            const int size = 1 << 16;
+            constexpr int size = 1 << 16;
             opampModel.reset();
-            resonance[n8] = new unsigned short[size];
 
             for (int vi = 0; vi < size; vi++)
             {
                 const double vin = vmin + vi * r_N16; /* vmin .. vmax */
-                resonance[n8][vi] = getNormalizedValue(opampModel.solve(resonance_n[n8], vin));
+                resonance[idx++] = getNormalizedValue(opampModel.solve(resonance_n[n8], vin));
             }
         }
     }
 
 public:
-    unsigned short** getVolume() { return volume; }
-    unsigned short** getResonance() { return resonance; }
-    unsigned short** getSummer() { return summer; }
-    unsigned short** getMixer() { return mixer; }
+    unsigned short* getVolume() { return volume; }
+    unsigned short* getResonance() { return resonance; }
+    unsigned short* getSummer() { return summer; }
+    unsigned short* getMixer() { return mixer; }
 
     inline unsigned short getOpampRev(int i) const { return opamp_rev[i]; }
     inline double getVddt() const { return Vddt; }
@@ -264,24 +293,18 @@ public:
 
     inline unsigned short getNormalizedValue(double value) const
     {
-        const double tmp = N16 * (value - vmin);
-        assert(tmp >= 0. && tmp <= 65535.);
-        return static_cast<unsigned short>(tmp + rnd.getNoise());
+        return to_ushort_dither(N16 * (value - vmin), rnd.getNoise());
     }
 
     template<int N>
     inline unsigned short getNormalizedCurrentFactor(double wl) const
     {
-        const double tmp = (1 << N) * currFactorCoeff * wl;
-        assert(tmp > -0.5 && tmp < 65535.5);
-        return static_cast<unsigned short>(tmp + 0.5);
+        return to_ushort((1 << N) * currFactorCoeff * wl);
     }
 
     inline unsigned short getNVmin() const
     {
-        const double tmp = N16 * vmin;
-        assert(tmp > -0.5 && tmp < 65535.5);
-        return static_cast<unsigned short>(tmp + 0.5);
+        return to_ushort(N16 * vmin);
     }
 
     inline int getNormalizedVoice(float value, unsigned int env) const
@@ -290,6 +313,24 @@ public:
     }
 };
 
+template<>
+struct FilterModelConfig::summer_offset<0>
+{
+    static constexpr int value = 0;
+};
+
+template<>
+struct FilterModelConfig::mixer_offset<1>
+{
+    static constexpr int value = 1;
+};
+
+template<>
+struct FilterModelConfig::mixer_offset<0>
+{
+    static constexpr int value = 0;
+};
+
 } // namespace reSIDfp
 
 #endif
