@@ -125,15 +125,15 @@ private:
     /// masks for the IRQ flags
     uint8_t irqMask;
 
+    /// memory for chip registers
+    uint8_t regs[0x40] = {0};
+
     /// Light pen
     Lightpen lp;
 
     /// the 8 sprites data
     Sprites sprites;
 
-    /// memory for chip registers
-    uint8_t regs[0x40];
-
     EventCallback<MOS656X> badLineStateChangeEvent;
 
     EventCallback<MOS656X> rasterYIRQEdgeDetectorEvent;
