@@ -21,7 +21,11 @@
 #ifndef C64CPU_H
 #define C64CPU_H
 
-#include "c64/c64env.h"
+#ifdef HAVE_CONFIG_H
+#  include "config.h"
+#endif
+
+#include "c64/mmu.h"
 #include "CPU/mos6510.h"
 
 #ifdef VICE_TESTSUITE
@@ -33,10 +37,6 @@
 
 #include "sidcxx11.h"
 
-#ifdef HAVE_CONFIG_H
-#  include "config.h"
-#endif
-
 namespace libsidplayfp
 {
 #ifdef PRINTSCREENCODES
@@ -65,18 +65,18 @@ static const char CHRtab[256] =
   0x2f,0x2d,0x2d,0x7c,0x7c,0x7c,0x7c,0x2d,0x2d,0x2d,0x2f,0x5c,0x5c,0x2f,0x2f,0x23
 };
 #endif
-class c64cpu final : public MOS6510
+class c64cpubus final : public CPUDataBus
 {
 private:
-    c64env &m_env;
+    MMU &m_mmu;
 
 protected:
-    uint8_t cpuRead(uint_least16_t addr) override { return m_env.cpuRead(addr); }
+    uint8_t cpuRead(uint_least16_t addr) override { return m_mmu.cpuRead(addr); }
 
     void cpuWrite(uint_least16_t addr, uint8_t data) override
     {
 #ifdef PRINTSCREENCODES
-        if (addr >= 1024 && addr <= 2047)
+        if (addr >= 0x0400 && addr <= 0x07ff)
         {
             std::cout << CHRtab[data];
         }
@@ -97,13 +97,12 @@ protected:
             }
         }
 #endif
-        m_env.cpuWrite(addr, data);
+        m_mmu.cpuWrite(addr, data);
     }
 
 public:
-    c64cpu (c64env &env) :
-        MOS6510(env.scheduler()),
-        m_env(env) {}
+    c64cpubus (MMU &mmu) :
+        m_mmu(mmu) {}
 };
 
 }
