@@ -1,7 +1,7 @@
 /*
  * This file is part of libsidplayfp, a SID player engine.
  *
- * Copyright 2011-2024 Leandro Nini <drfiemost@users.sourceforge.net>
+ * Copyright 2011-2025 Leandro Nini <drfiemost@users.sourceforge.net>
  * Copyright 2007-2010 Antti Lankila
  * Copyright 2000 Simon White
  *
@@ -86,7 +86,9 @@ public:
      * Set the fast-forward factor.
      *
      * @param percent
+     * @deprecated
      */
+    SID_DEPRECATED
     bool fastForward(unsigned int percent);
 
     /**
@@ -107,19 +109,81 @@ public:
      * @return the number of produced samples. If less than requested
      *         or #isPlaying() is false an error occurred, use #error()
      *         to get a detailed message.
+     * @deprecated use #play(unsigned int)
      */
+    SID_DEPRECATED
     uint_least32_t play(short *buffer, uint_least32_t count);
 
+    /**
+     * Get the buffer pointers for each of the installed SID chip.
+     *
+     * @param buffers pointer to the array of buffer pointers.
+     * @since 2.14
+     */
+    void buffers(short** buffers) const;
+
+    /**
+     * Run the emulation for selected number of cycles.
+     * The value will be limited to a reasonable amount
+     * if too large.
+     *
+     * @param cycles the number of cycles to run.
+     * @return the number of produced samples or zero
+     * for hardware devices. If negative an error occurred,
+     * use #error() to get a detailed message.
+     * @since 2.14
+     */
+    int play(unsigned int cycles);
+
+    /**
+     * Reinitialize the engine.
+     *
+     * @return false in case of error, use #error()
+     * to get a detailed message.
+     * @since 2.15
+     */
+    bool reset();
+
+    /**
+     * Get the number of installed SID chips.
+     *
+     * @return the number of SID chips.
+     * @since 2.14
+     */
+    unsigned int installedSIDs() const;
+
+    /**
+     * Init mixer.
+     *
+     * @param stereo whether to mix in stereo or mono
+     * @since 2.15
+     */
+    void initMixer(bool stereo);
+
+    /**
+     * Mix buffers.
+     *
+     * @param buffer the output buffer
+     * @param samples number of samples to mix, returned from the #play(unsigned int) function
+     * @return number of samples generated (samples for mono, samples*2 for stereo)
+     * @since 2.15
+     */
+    unsigned int mix(short *buffer, unsigned int samples);
+
     /**
      * Check if the engine is playing or stopped.
      *
      * @return true if playing, false otherwise.
+     * @deprecated
      */
+    SID_DEPRECATED
     bool isPlaying() const;
 
     /**
      * Stop the engine.
+     * @deprecated
      */
+    SID_DEPRECATED
     void stop();
 
     /**
